/*
 * Drehgeber-Schnittstelle
 *
 * main.c
 *
 * Ein Gray-Drehgebersignal abfragen und auf dem virtuellen COM-Port per USB ausgeben
 *
 * Hardware:
 * Eval Board mit den folgenden Anschluessen:
 *     USB+                  -> PA12
 *     USB-                  -> PA11
 *     Encoder A             -> PB6
 *     Encoder B             -> PB7
 *     load indicator output -> PB8
 *
 * Die Implementierung basiert groesstenteils auf einem Implementierungsbeispiel
 * der USB-FS-Library
 * STM32_USB-FS-Device_Lib_V4.1.0\Projects\Virtual_COM_Port
 *
 * $Date: 2019-02-09 12:08:16 +0100 (Sa, 09 Feb 2019) $
 * $Revision: 17 $
 *
 * 06.02.2019 Nicolas
 */


/* Includes ------------------------------------------------------------------*/
#include "hardware_config.h"
#include "hw_config.h"
#include "usb_lib.h"
#include "usb_desc.h"
#include "usb_pwr.h"
#include <stdio.h>
#include <stdbool.h>
#include <string.h>
#include <float.h>



/* Extern variables ----------------------------------------------------------*/
extern __IO uint8_t Receive_Buffer[64];
extern __IO  uint32_t Receive_length ;
extern __IO  uint32_t length;

/* Private variables ---------------------------------------------------------*/
uint8_t Send_Buffer[64];
uint32_t packet_sent=1;
uint32_t packet_receive=1;


/* Private function prototypes -----------------------------------------------*/




volatile uint32_t rawdata = 0;           // Data telegram from dial gauge/caliper
volatile bool newDataAvailable = false;  // Set in ISR, cleared in main()
volatile uint32_t gTime_ms = 0;          // Global time stamp, set only in SysTick handle




/* Interprete data telegrams (24 Bits) and send to virtual COM Port as text string */
int main(void)
{
    GPIO_InitTypeDef   GPIO_InitStructure;

    SystemInit();
    SysTick_Config(SystemCoreClock/1000*(SYSTICK_TIMER_INTERVAL_MS));

    Set_System();
    Set_USBClock();
    USB_Interrupts_Config();
    USB_Init();



    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);

    /* Configure the GPIO_LED pin */
    GPIO_InitStructure.GPIO_Pin = SPARE0_Pin;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
    GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;

    GPIO_Init(SPARE0_GPIO, &GPIO_InitStructure);


    // Initialize Encoder

    // Input with pull-ups
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB | RCC_APB2Periph_AFIO, ENABLE);
    RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM4, ENABLE);

    GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6 | GPIO_Pin_7;
    GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPU;
    GPIO_Init(GPIOB, &GPIO_InitStructure);

    // Encoder Timer
	TIM_EncoderInterfaceConfig(TIM4, TIM_EncoderMode_TI12, \
					TIM_ICPolarity_Rising, TIM_ICPolarity_Falling);
    TIM_Cmd(TIM4, ENABLE);



    while (1)
    {
        if (bDeviceState == CONFIGURED)
        {
            /* Receiver virtual UART, just to discard it */
            CDC_Receive_DATA();

            if( newDataAvailable == true )
            {
                // Show workload SPARE0 (set)
                SPARE0_GPIO->BSRR = SPARE0_Pin;

                if( packet_sent == 1 )
                {
                    uint32_t data = rawdata;
                    int bufferlen;
                    bufferlen = snprintf(Send_Buffer, 30, "T=0x%04lx, V=0x%04lx\r\n",
                            data>>16, data & 0xFFFF);

                    CDC_Send_DATA (Send_Buffer, bufferlen);

                    newDataAvailable = false;
                }

            // Show workload SPARE0 (clear)
            SPARE0_GPIO->BSRR = (uint32_t) SPARE0_Pin<<16U;
            }
        }
    }
}



/* Read rotary encoder and generate time stamps */
void SysTick_Handler(void)
{
    gTime_ms+=SYSTICK_TIMER_INTERVAL_MS;

    uint16_t enc = TIM_GetCounter(TIM4);
    uint16_t timestamp = gTime_ms;

    uint32_t raw = timestamp<<16 | enc;

    rawdata = raw;
    newDataAvailable = true;
}

